@@ -1,5 +1,6 @@
 """reader - uses a reader function to read frames from videos"""
 import multiprocessing
+import random
 
 from .read_vids_cv2 import read_vids
 from .shared_queue import SharedQueue
@@ -29,13 +30,16 @@ class FrameReader:
           workers - number of Processes to distribute video reading to.
           memory_size - number of GB of shared_memory
         """
+        self.n_vids = len(vids)
+        random.shuffle(vids)  # shuffle videos so each shard has approximately equal sum of video lengths
 
-        memory_size_b = memory_size * 1024**3  # GB -> bytes
+        memory_size_b = int(memory_size * 1024**3)  # GB -> bytes
         shared_blocks = memory_size_b // (resize_size**2 * 3 * (1 if batch_size == -1 else batch_size))
         dim12 = (shared_blocks,) if batch_size == -1 else (shared_blocks, batch_size)
         self.shared_queue = SharedQueue.from_shape([*dim12, resize_size, resize_size, 3])
 
         div_vids = [vids[int(len(vids) * i / workers) : int(len(vids) * (i + 1) / workers)] for i in range(workers)]
+
         self.procs = [
             multiprocessing.Process(
                 args=(work, worker_id, take_every_nth, resize_size, batch_size, self.shared_queue.export()),
@@ -45,6 +49,9 @@ class FrameReader:
             for worker_id, work in enumerate(div_vids)
         ]
 
+    def __len__(self):
+        return self.n_vids
+
     def __iter__(self):
         return self
 
